@@ -1,4 +1,4 @@
-//@line 62 "/icecat-3.6.8/browser/base/content/nsContextMenu.js"
+//@line 62 "/icecat-3.6/browser/base/content/nsContextMenu.js"
 
 function nsContextMenu(aXulMenu, aBrowser) {
   this.target            = null;
@@ -27,7 +27,7 @@ function nsContextMenu(aXulMenu, aBrowser) {
   this.isContentSelected = false;
   this.shouldDisplay     = true;
   this.isDesignMode      = false;
-  this.onEditableArea = false;
+  this.possibleSpellChecking = false;
   this.ellipsis = "\u2026";
   try {
     this.ellipsis = gPrefService.getComplexValue("intl.ellipsis",
@@ -147,12 +147,12 @@ nsContextMenu.prototype = {
     // Set as Desktop background depends on whether an image was clicked on,
     // and only works if we have a shell service.
     var haveSetDesktopBackground = false;
-//@line 211 "/icecat-3.6.8/browser/base/content/nsContextMenu.js"
+//@line 211 "/icecat-3.6/browser/base/content/nsContextMenu.js"
     // Only enable Set as Desktop Background if we can get the shell service.
     var shell = getShellService();
     if (shell)
       haveSetDesktopBackground = true;
-//@line 216 "/icecat-3.6.8/browser/base/content/nsContextMenu.js"
+//@line 216 "/icecat-3.6/browser/base/content/nsContextMenu.js"
     this.showItem("context-setDesktopBackground",
                   haveSetDesktopBackground && this.onLoadedImage);
 
@@ -246,7 +246,7 @@ nsContextMenu.prototype = {
     var canSpell = InlineSpellCheckerUI.canSpellCheck;
     var onMisspelling = InlineSpellCheckerUI.overMisspelling;
     this.showItem("spell-check-enabled", canSpell);
-    this.showItem("spell-separator", canSpell || this.onEditableArea);
+    this.showItem("spell-separator", canSpell || this.possibleSpellChecking);
     if (canSpell) {
       document.getElementById("spell-check-enabled")
               .setAttribute("checked", InlineSpellCheckerUI.enabled);
@@ -274,7 +274,7 @@ nsContextMenu.prototype = {
       InlineSpellCheckerUI.addDictionaryListToMenu(dictMenu, dictSep);
       this.showItem("spell-add-dictionaries-main", false);
     }
-    else if (this.onEditableArea) {
+    else if (this.possibleSpellChecking) {
       // when there is no spellchecker but we might be able to spellcheck
       // add the add to dictionaries item. This will ensure that people
       // with no dictionaries will be able to download them
@@ -316,10 +316,10 @@ nsContextMenu.prototype = {
     this.showItem("context-sep-copylink", this.onLink &&
                   (this.onImage || this.onVideo || this.onAudio));
 
-//@line 380 "/icecat-3.6.8/browser/base/content/nsContextMenu.js"
+//@line 380 "/icecat-3.6/browser/base/content/nsContextMenu.js"
     // Copy image contents depends on whether we're on an image.
     this.showItem("context-copyimage-contents", this.onImage);
-//@line 383 "/icecat-3.6.8/browser/base/content/nsContextMenu.js"
+//@line 383 "/icecat-3.6/browser/base/content/nsContextMenu.js"
     // Copy image location depends on whether we're on an image.
     this.showItem("context-copyimage", this.onImage);
     this.showItem("context-copyvideourl", this.onVideo);
@@ -382,7 +382,7 @@ nsContextMenu.prototype = {
     this.inFrame           = false;
     this.hasBGImage        = false;
     this.bgImageURL        = "";
-    this.onEditableArea = false;
+    this.possibleSpellChecking = false;
 
     // Clear any old spellchecking items from the menu, this used to
     // be in the menu hiding code but wasn't getting called in all
@@ -431,7 +431,7 @@ nsContextMenu.prototype = {
         // allow spellchecking UI on all writable text boxes except passwords
         if (this.onTextInput && ! this.target.readOnly &&
             this.target.type != "password") {
-          this.onEditableArea = true;
+          this.possibleSpellChecking = true;
           InlineSpellCheckerUI.init(this.target.QueryInterface(Ci.nsIDOMNSEditableElement).editor);
           InlineSpellCheckerUI.initFromEvent(aRangeParent, aRangeOffset);
         }
@@ -440,7 +440,7 @@ nsContextMenu.prototype = {
       else if (this.target instanceof HTMLTextAreaElement) {
         this.onTextInput = true;
         if (!this.target.readOnly) {
-          this.onEditableArea = true;
+          this.possibleSpellChecking = true;
           InlineSpellCheckerUI.init(this.target.QueryInterface(Ci.nsIDOMNSEditableElement).editor);
           InlineSpellCheckerUI.initFromEvent(aRangeParent, aRangeOffset);
         }
@@ -541,41 +541,39 @@ nsContextMenu.prototype = {
       this.inFrame = true;
 
     // if the document is editable, show context menu like in text inputs
-    if (!this.onEditableArea) {
-      var win = this.target.ownerDocument.defaultView;
-      if (win) {
-        var isEditable = false;
-        try {
-          var editingSession = win.QueryInterface(Ci.nsIInterfaceRequestor)
-                                  .getInterface(Ci.nsIWebNavigation)
-                                  .QueryInterface(Ci.nsIInterfaceRequestor)
-                                  .getInterface(Ci.nsIEditingSession);
-          if (editingSession.windowIsEditable(win) &&
-              this.getComputedStyle(this.target, "-moz-user-modify") == "read-write") {
-            isEditable = true;
-          }
-        }
-        catch(ex) {
-          // If someone built with composer disabled, we can't get an editing session.
+    var win = this.target.ownerDocument.defaultView;
+    if (win) {
+      var isEditable = false;
+      try {
+        var editingSession = win.QueryInterface(Ci.nsIInterfaceRequestor)
+                                .getInterface(Ci.nsIWebNavigation)
+                                .QueryInterface(Ci.nsIInterfaceRequestor)
+                                .getInterface(Ci.nsIEditingSession);
+        if (editingSession.windowIsEditable(win) &&
+            this.getComputedStyle(this.target, "-moz-user-modify") == "read-write") {
+          isEditable = true;
         }
+      }
+      catch(ex) {
+        // If someone built with composer disabled, we can't get an editing session.
+      }
 
-        if (isEditable) {
-          this.onTextInput       = true;
-          this.onKeywordField    = false;
-          this.onImage           = false;
-          this.onLoadedImage     = false;
-          this.onCompletedImage  = false;
-          this.onMathML          = false;
-          this.inFrame           = false;
-          this.hasBGImage        = false;
-          this.isDesignMode      = true;
-          this.onEditableArea = true;
-          InlineSpellCheckerUI.init(editingSession.getEditorForWindow(win));
-          var canSpell = InlineSpellCheckerUI.canSpellCheck;
-          InlineSpellCheckerUI.initFromEvent(aRangeParent, aRangeOffset);
-          this.showItem("spell-check-enabled", canSpell);
-          this.showItem("spell-separator", canSpell);
-        }
+      if (isEditable) {
+        this.onTextInput       = true;
+        this.onKeywordField    = false;
+        this.onImage           = false;
+        this.onLoadedImage     = false;
+        this.onCompletedImage  = false;
+        this.onMathML          = false;
+        this.inFrame           = false;
+        this.hasBGImage        = false;
+        this.isDesignMode      = true;
+        this.possibleSpellChecking = true;
+        InlineSpellCheckerUI.init(editingSession.getEditorForWindow(win));
+        var canSpell = InlineSpellCheckerUI.canSpellCheck;
+        InlineSpellCheckerUI.initFromEvent(aRangeParent, aRangeOffset);
+        this.showItem("spell-check-enabled", canSpell);
+        this.showItem("spell-separator", canSpell);
       }
     }
   },
@@ -779,12 +777,12 @@ nsContextMenu.prototype = {
     // Confirm since it's annoying if you hit this accidentally.
     const kDesktopBackgroundURL = 
                   "chrome://browser/content/setDesktopBackground.xul";
-//@line 858 "/icecat-3.6.8/browser/base/content/nsContextMenu.js"
+//@line 856 "/icecat-3.6/browser/base/content/nsContextMenu.js"
     // On non-Mac platforms, the Set Wallpaper dialog is modal.
     openDialog(kDesktopBackgroundURL, "",
                "centerscreen,chrome,dialog,modal,dependent",
                this.target);
-//@line 863 "/icecat-3.6.8/browser/base/content/nsContextMenu.js"
+//@line 861 "/icecat-3.6/browser/base/content/nsContextMenu.js"
   },
 
   // Save URL of clicked-on frame.
