@@ -1,4 +1,4 @@
-//@line 39 "/icecat-3.6.8/browser/components/preferences/advanced.js"
+//@line 39 "/icecat-3.6/browser/components/preferences/advanced.js"
 
 // Load DownloadUtils module for convertByteUnits
 Components.utils.import("resource://gre/modules/DownloadUtils.jsm");
@@ -23,9 +23,8 @@ var gAdvancedPane = {
         advancedPrefs.selectedIndex = preference.value;
     }
 
-//@line 68 "/icecat-3.6.8/browser/components/preferences/advanced.js"
+//@line 68 "/icecat-3.6/browser/components/preferences/advanced.js"
     this.updateOfflineApps();
-//@line 72 "/icecat-3.6.8/browser/components/preferences/advanced.js"
   },
 
   /**
@@ -99,35 +98,6 @@ var gAdvancedPane = {
     return checkbox.checked ? (this._storedSpellCheck == 2 ? 2 : 1) : 0;
   },
 
-  /**
-   *
-   */
-  initSubmitCrashes: function ()
-  {
-    var checkbox = document.getElementById("submitCrashesBox");
-    try {
-      var cr = Components.classes["@mozilla.org/toolkit/crash-reporter;1"].
-               getService(Components.interfaces.nsICrashReporter_MOZILLA_1_9_2_BRANCH);
-      checkbox.checked = cr.submitReports;
-    } catch (e) {
-      checkbox.style.display = "none";
-    }
-  },
-
-  /**
-   *
-   */
-  updateSubmitCrashes: function ()
-  {
-    var checkbox = document.getElementById("submitCrashesBox");
-    try {
-      var cr = Components.classes["@mozilla.org/toolkit/crash-reporter;1"].
-               getService(Components.interfaces.nsICrashReporter);
-      cr.submitReports = checkbox.checked;
-    } catch (e) { }
-  },
-
-
   // NETWORK TAB
 
   /*
@@ -387,7 +357,7 @@ var gAdvancedPane = {
    *             iii 0/1/2   t         true   
    * 
    */
-//@line 531 "/icecat-3.6.8/browser/components/preferences/advanced.js"
+//@line 499 "/icecat-3.6/browser/components/preferences/advanced.js"
 
   /**
    * The Extensions checkbox and button are disabled only if the enable Addon
@@ -457,7 +427,7 @@ var gAdvancedPane = {
                                         "chrome://pippki/content/device_manager.xul",
                                         "", null);
   }
-//@line 601 "/icecat-3.6.8/browser/components/preferences/advanced.js"
+//@line 569 "/icecat-3.6/browser/components/preferences/advanced.js"
   ,
 
   // SYSTEM DEFAULTS
@@ -503,5 +473,5 @@ var gAdvancedPane = {
       psvc.alert(window, promptTitle, promptMessage);
     }
   }
-//@line 647 "/icecat-3.6.8/browser/components/preferences/advanced.js"
+//@line 615 "/icecat-3.6/browser/components/preferences/advanced.js"
 };
