@@ -1,4 +1,4 @@
-//@line 37 "/icecat-3.6.8/browser/components/nsBrowserContentHandler.js"
+//@line 37 "/icecat-3.6/browser/components/nsBrowserContentHandler.js"
 
 const nsISupports            = Components.interfaces.nsISupports;
 
@@ -455,7 +455,7 @@ var nsBrowserContentHandler = {
       cmdLine.preventDefault = true;
     }
 
-//@line 506 "/icecat-3.6.8/browser/components/nsBrowserContentHandler.js"
+//@line 506 "/icecat-3.6/browser/components/nsBrowserContentHandler.js"
   },
 
   helpInfo : "  -browser            Open a browser window.\n",
@@ -664,13 +664,13 @@ var nsDefaultCommandLineHandler = {
   // running and have already been handled. This is compared against uri's
   // opened using DDE on Win32 so we only open one of the requests.
   _handledURIs: [ ],
-//@line 717 "/icecat-3.6.8/browser/components/nsBrowserContentHandler.js"
+//@line 717 "/icecat-3.6/browser/components/nsBrowserContentHandler.js"
 
   /* nsICommandLineHandler */
   handle : function dch_handle(cmdLine) {
     var urilist = [];
 
-//@line 743 "/icecat-3.6.8/browser/components/nsBrowserContentHandler.js"
+//@line 743 "/icecat-3.6/browser/components/nsBrowserContentHandler.js"
 
     try {
       var ar;
@@ -749,7 +749,7 @@ var nsDefaultCommandLineHandler = {
   },
 
   // XXX localize me... how?
-  helpInfo : " Usage: icecat [-flags] [<url>]\n",
+  helpInfo : "Usage: firefox [-flags] [<url>]\n",
 
   /* nsIFactory */
   createInstance: function dch_CI(outer, iid) {
@@ -825,9 +825,9 @@ var Module = {
 
     registerType("text/html");
     registerType("application/vnd.mozilla.xul+xml");
-//@line 898 "/icecat-3.6.8/browser/components/nsBrowserContentHandler.js"
+//@line 898 "/icecat-3.6/browser/components/nsBrowserContentHandler.js"
     registerType("image/svg+xml");
-//@line 900 "/icecat-3.6.8/browser/components/nsBrowserContentHandler.js"
+//@line 900 "/icecat-3.6/browser/components/nsBrowserContentHandler.js"
     registerType("text/rdf");
     registerType("text/xml");
     registerType("application/xhtml+xml");
