@@ -1,12 +1,12 @@
-//@line 37 "/icecat-3.6.8/browser/app/profile/firefox.js"
+//@line 37 "/icecat-3.6/browser/app/profile/firefox.js"
 
 // XXX Toolkit-specific preferences should be moved into toolkit.js
 
-//@line 41 "/icecat-3.6.8/browser/app/profile/firefox.js"
+//@line 41 "/icecat-3.6/browser/app/profile/firefox.js"
 
-//@line 44 "/icecat-3.6.8/browser/app/profile/firefox.js"
+//@line 44 "/icecat-3.6/browser/app/profile/firefox.js"
 
-//@line 50 "/icecat-3.6.8/browser/app/profile/firefox.js"
+//@line 50 "/icecat-3.6/browser/app/profile/firefox.js"
 
 pref("general.startup.browser", true);
 
@@ -29,13 +29,14 @@ pref("extensions.logging.enabled", false);
 pref("extensions.hideInstallButton", true);
 
 // Preferences for the Get Add-ons pane
-pref("extensions.getAddons.showPane", false);
-pref("extensions.getAddons.browseAddons", "http://www.gnu.org/software/gnuzilla/addons.html");
-pref("extensions.getAddons.maxResults", 5);
-pref("extensions.getAddons.recommended.browseURL", "http://www.gnu.org/software/gnuzilla/addons.html");
-pref("extensions.getAddons.recommended.url", "http://www.gnu.org/software/gnuzilla/addons.html");
-pref("extensions.getAddons.search.browseURL", "http://www.gnu.org/software/gnuzilla/addons.html");
-pref("extensions.getAddons.search.url", "http://www.gnu.org/software/gnuzilla/addons.html");
+pref ("extensions.getAddons.showPane", false);
+pref ("extensions.getAddons.browseAddons", "http://www.gnu.org/software/gnuzilla/");
+pref ("extensions.getAddons.maxResults", 5);
+pref ("extensions.getAddons.recommended.browseURL", "http://www.gnu.org/software/gnuzilla/addons.html");
+pref ("extensions.getAddons.recommended.url", "http://www.gnu.org/software/gnuzilla/addons.html");
+pref ("extensions.getAddons.search.browseURL", "http://www.gnu.org/software/gnuzilla/addons.html");
+pref ("extensions.getAddons.search.url", "http://www.gnu.org/software/gnuzilla/addons.html");
+
 
 // Blocklist preferences
 pref("extensions.blocklist.enabled", true);
@@ -49,16 +50,8 @@ pref("extensions.blocklist.detailsURL", "https://www.mozilla.com/%LOCALE%/blockl
 // Dictionary download preference
 pref("browser.dictionaries.download.url", "http://gnuzilla.gnu.org");
 
-// Update Timer Manager preferences
-// Interval: When all registered timers should be checked (in milliseconds)
-//           default=10 minutes
-pref("app.update.timer", 600000);
-
 // App-specific update preferences
 
-// The interval to check for updates (app.update.interval) is defined in
-// firefox-branding.js
-
 // Whether or not app updates are enabled
 pref("app.update.enabled", true);
 
@@ -95,6 +88,9 @@ pref("app.update.url", "https://aus2.mozilla.org/update/3/%PRODUCT%/%VERSION%/%B
 //           latest download (in seconds) default=1 day
 pref("app.update.nagTimer.restart", 86400);
 
+// Interval: When all registered timers should be checked (in milliseconds)
+//           default=10 minutes
+pref("app.update.timer", 600000);
 // Give the user x seconds to react before showing the big UI. default=12 hours
 pref("app.update.promptWaitTime", 43200);
 // Show the Update Checking/Ready UI when the user was idle for x seconds
@@ -118,38 +114,35 @@ pref("app.update.incompatible.mode", 0);
 // e.g.
 //  extensions.{GUID}.update.enabled
 //  extensions.{GUID}.update.url
+//  extensions.{GUID}.update.interval
 //  .. etc ..
 //
 pref("extensions.update.enabled", true);
-pref("extensions.update.url", "https://versioncheck.addons.mozilla.org/update/VersionCheck.php?reqVersion=%REQ_VERSION%&id=%ITEM_ID%&version=%ITEM_VERSION%&maxAppVersion=%ITEM_MAXAPPVERSION%&status=%ITEM_STATUS%&appID=%APP_ID%&appVersion=%APP_VERSION%&appOS=%APP_OS%&appABI=%APP_ABI%&locale=%APP_LOCALE%&currentAppVersion=%CURRENT_APP_VERSION%&updateType=%UPDATE_TYPE%");
+pref("extensions.update.url", "https://versioncheck.addons.mozilla.org/update/VersionCheck.php?reqVersion=%REQ_VERSION%&id=%ITEM_ID%&version=%ITEM_VERSION%&maxAppVersion=%ITEM_MAXAPPVERSION%&status=%ITEM_STATUS%&appID=%APP_ID%&appVersion=%APP_VERSION%&appOS=%APP_OS%&appABI=%APP_ABI%&locale=%APP_LOCALE%&currentAppVersion=%CURRENT_APP_VERSION%");
 pref("extensions.update.interval", 86400);  // Check for updates to Extensions and 
                                             // Themes every day
 // Non-symmetric (not shared by extensions) extension-specific [update] preferences
 pref("extensions.getMoreExtensionsURL", "http://www.gnu.org/software/gnuzilla/addons.html#addons");
 pref("extensions.getMoreThemesURL", "http://www.gnu.org/software/gnuzilla/addons.html#themes");
+pref("extensions.getMorePluginsURL", "http://www.gnu.org/software/gnuzilla/addons.html");
 pref("extensions.dss.enabled", false);          // Dynamic Skin Switching                                               
 pref("extensions.dss.switchPending", false);    // Non-dynamic switch pending after next
                                                 // restart.
 
-pref("extensions.{972ce4c6-7e08-4474-a285-3208198ce6fd}.name", "chrome://browser/locale/browser.properties");
-pref("extensions.{972ce4c6-7e08-4474-a285-3208198ce6fd}.description", "chrome://browser/locale/browser.properties");
-
-pref("xpinstall.whitelist.add", "addons.mozilla.org");
-pref("xpinstall.whitelist.add.36", "getpersonas.com");
-
-pref("lightweightThemes.update.enabled", true);
+pref("xpinstall.whitelist.add", "update.mozilla.org");
+pref("xpinstall.whitelist.add.103", "addons.mozilla.org");
 
 pref("keyword.enabled", true);
 pref("keyword.URL", "chrome://browser-region/locale/region.properties");
 
 pref("general.useragent.locale", "en-US");
 pref("general.skins.selectedSkin", "classic/1.0");
-pref("general.useragent.extra.firefox", "IceCat/3.6.8 (like Firefox/3.6.8)");
+pref("general.useragent.extra.firefox", "IceCat/3.6 (like Firefox/3.6)");
 
 pref("general.smoothScroll", false);
-//@line 191 "/icecat-3.6.8/browser/app/profile/firefox.js"
+//@line 184 "/icecat-3.6/browser/app/profile/firefox.js"
 pref("general.autoScroll", false);
-//@line 195 "/icecat-3.6.8/browser/app/profile/firefox.js"
+//@line 188 "/icecat-3.6/browser/app/profile/firefox.js"
 
 // Whether or not the application should check at startup each time if it 
 // is the default browser.
@@ -163,16 +156,17 @@ pref("browser.startup.homepage",            "resource:/browserconfig.properties"
 pref("browser.enable_automatic_image_resizing", true);
 pref("browser.chrome.site_icons", true);
 pref("browser.chrome.favicons", true);
+pref("browser.formfill.enable", true);
 pref("browser.warnOnQuit", true);
 pref("browser.warnOnRestart", true);
 pref("browser.fullscreen.autohide", true);
 pref("browser.fullscreen.animateUp", 1);
 
-//@line 214 "/icecat-3.6.8/browser/app/profile/firefox.js"
+//@line 208 "/icecat-3.6/browser/app/profile/firefox.js"
 pref("browser.urlbar.clickSelectsAll", false);
-//@line 219 "/icecat-3.6.8/browser/app/profile/firefox.js"
+//@line 213 "/icecat-3.6/browser/app/profile/firefox.js"
 pref("browser.urlbar.doubleClickSelectsAll", true);
-//@line 223 "/icecat-3.6.8/browser/app/profile/firefox.js"
+//@line 217 "/icecat-3.6/browser/app/profile/firefox.js"
 pref("browser.urlbar.autoFill", false);
 // 0: Match anywhere (e.g., middle of words)
 // 1: Match on word boundaries and then try matching anywhere
@@ -183,10 +177,11 @@ pref("browser.urlbar.filter.javascript", true);
 
 // the maximum number of results to show in autocomplete when doing richResults
 pref("browser.urlbar.maxRichResults", 12);
-// The amount of time (ms) to wait after the user has stopped typing
-// before starting to perform autocomplete.  50 is the default set in
-// autocomplete.xml.
-pref("browser.urlbar.delay", 50);
+// Size of "chunks" affects the number of places to process between each search
+// timeout (ms). Too big and the UI will be unresponsive; too small and we'll
+// be waiting on the timeout too often without many results.
+pref("browser.urlbar.search.chunkSize", 1000);
+pref("browser.urlbar.search.timeout", 100);
 
 // The special characters below can be typed into the urlbar to either restrict
 // the search to visited history, bookmarked, tagged pages; or force a match on
@@ -213,10 +208,7 @@ pref("browser.urlbar.default.behavior", 0);
 pref("browser.download.saveLinkAsFilenameTimeout", 1000);
 
 pref("browser.download.useDownloadDir", true);
-
-//@line 268 "/icecat-3.6.8/browser/app/profile/firefox.js"
 pref("browser.download.folderList", 1);
-//@line 270 "/icecat-3.6.8/browser/app/profile/firefox.js"
 pref("browser.download.manager.showAlertOnComplete", true);
 pref("browser.download.manager.showAlertInterval", 2000);
 pref("browser.download.manager.retention", 2);
@@ -261,12 +253,11 @@ pref("browser.microsummary.updateGenerators", true);
 // enable search suggestions by default
 pref("browser.search.suggest.enabled", true);
 
+pref("browser.history.grouping", "day");
 pref("browser.history.showSessions", false);
 pref("browser.sessionhistory.max_entries", 50);
-//@line 317 "/icecat-3.6.8/browser/app/profile/firefox.js"
 pref("browser.history_expire_days", 180);
 pref("browser.history_expire_days_min", 90);
-//@line 323 "/icecat-3.6.8/browser/app/profile/firefox.js"
 pref("browser.history_expire_sites", 40000);
 
 // handle links targeting new windows
@@ -279,11 +270,8 @@ pref("browser.link.open_newwindow", 3);
 pref("browser.link.open_newwindow.restriction", 2);
 
 // Tabbed browser
-//@line 336 "/icecat-3.6.8/browser/app/profile/firefox.js"
 pref("browser.tabs.autoHide", false);
-//@line 340 "/icecat-3.6.8/browser/app/profile/firefox.js"
 pref("browser.tabs.closeWindowWithLastTab", true);
-pref("browser.tabs.insertRelatedAfterCurrent", true);
 pref("browser.tabs.warnOnClose", true);
 pref("browser.tabs.warnOnOpen", true);
 pref("browser.tabs.maxOpenBeforeWarn", 15);
@@ -310,8 +298,7 @@ pref("browser.tabs.closeButtons", 1);
 // false  return to the adjacent tab (old default)
 pref("browser.tabs.selectOwnerOnClose", true);
 
-pref("browser.allTabs.previews", false);
-pref("browser.ctrlTab.previews", false);
+pref("browser.ctrlTab.previews", true);
 pref("browser.ctrlTab.recentlyUsedLimit", 7);
 
 // Default bookmark sorting
@@ -331,11 +318,9 @@ pref("browser.bookmarks.max_backups",             5);
 
 // Scripts & Windows prefs
 pref("dom.disable_open_during_load",              true);
-//@line 393 "/icecat-3.6.8/browser/app/profile/firefox.js"
+//@line 372 "/icecat-3.6/browser/app/profile/firefox.js"
 pref("javascript.options.showInConsole",          false);
-//@line 395 "/icecat-3.6.8/browser/app/profile/firefox.js"
-
-//@line 400 "/icecat-3.6.8/browser/app/profile/firefox.js"
+//@line 374 "/icecat-3.6/browser/app/profile/firefox.js"
 
 // Make the status bar reliably present and unaffected by pages
 pref("dom.disable_window_open_feature.status",    true);
@@ -402,7 +387,7 @@ pref("intl.charsetmenu.browser.more2",  "chrome://global/locale/intl.properties"
 pref("intl.charsetmenu.browser.more3",  "chrome://global/locale/intl.properties");
 pref("intl.charsetmenu.browser.more4",  "chrome://global/locale/intl.properties");
 pref("intl.charsetmenu.browser.more5",  "chrome://global/locale/intl.properties");
-pref("intl.charsetmenu.browser.unicode",  "UTF-8, UTF-16LE, UTF-16BE, UTF-32, UTF-32LE, UTF-32BE");
+pref("intl.charsetmenu.browser.unicode",  "chrome://global/locale/intl.properties");
 pref("intl.charset.detector", "chrome://global/locale/intl.properties");
 pref("intl.charset.default",  "chrome://global-platform/locale/intl.properties");
 pref("font.language.group", "chrome://global/locale/intl.properties");
@@ -414,10 +399,10 @@ pref("browser.gesture.swipe.left", "Browser:BackOrBackDuplicate");
 pref("browser.gesture.swipe.right", "Browser:ForwardOrForwardDuplicate");
 pref("browser.gesture.swipe.up", "cmd_scrollTop");
 pref("browser.gesture.swipe.down", "cmd_scrollBottom");
-//@line 482 "/icecat-3.6.8/browser/app/profile/firefox.js"
+//@line 456 "/icecat-3.6/browser/app/profile/firefox.js"
 pref("browser.gesture.pinch.latched", false);
 pref("browser.gesture.pinch.threshold", 25);
-//@line 485 "/icecat-3.6.8/browser/app/profile/firefox.js"
+//@line 459 "/icecat-3.6/browser/app/profile/firefox.js"
 pref("browser.gesture.pinch.out", "cmd_fullZoomEnlarge");
 pref("browser.gesture.pinch.in", "cmd_fullZoomReduce");
 pref("browser.gesture.pinch.out.shift", "cmd_fullZoomReset");
@@ -429,7 +414,7 @@ pref("browser.gesture.twist.left", "");
 pref("browser.gesture.tap", "cmd_fullZoomReset");
 
 // 0=lines, 1=pages, 2=history , 3=text size
-//@line 510 "/icecat-3.6.8/browser/app/profile/firefox.js"
+//@line 484 "/icecat-3.6/browser/app/profile/firefox.js"
 pref("mousewheel.withshiftkey.action",2);
 pref("mousewheel.withshiftkey.sysnumlines",false);
 pref("mousewheel.withshiftkey.numlines",1);
@@ -439,7 +424,7 @@ pref("mousewheel.withaltkey.numlines",1);
 pref("mousewheel.withmetakey.action",0);
 pref("mousewheel.withmetakey.sysnumlines",true);
 pref("mousewheel.withmetakey.numlines",1);
-//@line 520 "/icecat-3.6.8/browser/app/profile/firefox.js"
+//@line 494 "/icecat-3.6/browser/app/profile/firefox.js"
 pref("mousewheel.withcontrolkey.action",3);
 pref("mousewheel.withcontrolkey.sysnumlines",false);
 pref("mousewheel.withcontrolkey.numlines",1);
@@ -494,20 +479,16 @@ pref("accessibility.typeaheadfind.flashBar", 1);
 pref("plugin.default_plugin_disabled", true);
 
 // plugin finder service url
-pref("pfs.datasource.url", "http://gnuzilla.gnu.org/plugins/PluginFinderService.php?mimetype=%PLUGIN_MIMETYPE%&appID=%APP_ID%&appVersion=%APP_VERSION%&clientOS=%CLIENT_OS%&chromeLocale=%CHROME_LOCALE%&appRelease=%APP_RELEASE%");
+pref("pfs.datasource.url", "http://www.gnu.org/software/gnuzilla/");
 
-// by default we show an infobar message when pages require plugins the user has not installed, or are outdated
-pref("plugins.hide_infobar_for_missing_plugin", false);
-pref("plugins.hide_infobar_for_outdated_plugin", false);
+// by default we show an infobar message when pages require plugins the user has not installed
+pref("plugins.hide_infobar_for_missing_plugin", true);
 
-pref("plugins.update.url", "https://www.mozilla.com/%LOCALE%/plugincheck/");
-pref("plugins.update.notifyUser", false);
-
-//@line 586 "/icecat-3.6.8/browser/app/profile/firefox.js"
+//@line 556 "/icecat-3.6/browser/app/profile/firefox.js"
 pref("browser.preferences.instantApply", true);
-//@line 591 "/icecat-3.6.8/browser/app/profile/firefox.js"
+//@line 561 "/icecat-3.6/browser/app/profile/firefox.js"
 pref("browser.preferences.animateFadeIn", false);
-//@line 593 "/icecat-3.6.8/browser/app/profile/firefox.js"
+//@line 563 "/icecat-3.6/browser/app/profile/firefox.js"
 
 pref("browser.download.show_plugins_in_list", true);
 pref("browser.download.hide_plugins_without_extensions", true);
@@ -516,9 +497,9 @@ pref("browser.download.hide_plugins_without_extensions", true);
 // 0 goes Back/Forward
 // 1 act like PgUp/PgDown
 // 2 and other values, nothing
-//@line 602 "/icecat-3.6.8/browser/app/profile/firefox.js"
+//@line 572 "/icecat-3.6/browser/app/profile/firefox.js"
 pref("browser.backspace_action", 2);
-//@line 606 "/icecat-3.6.8/browser/app/profile/firefox.js"
+//@line 576 "/icecat-3.6/browser/app/profile/firefox.js"
 
 // this will automatically enable inline spellchecking (if it is available) for
 // editable elements in HTML
@@ -607,7 +588,7 @@ pref("gecko.handlerService.schemes.ircs.3.uriTemplate", "chrome://browser-region
 // By default, we don't want protocol/content handlers to be registered from a different host, see bug 402287
 pref("gecko.handlerService.allowRegisterFromDifferentHost", false);
 
-//@line 695 "/icecat-3.6.8/browser/app/profile/firefox.js"
+//@line 665 "/icecat-3.6/browser/app/profile/firefox.js"
 // Safe browsing does nothing unless this pref is set
 pref("browser.safebrowsing.enabled", true);
 
@@ -634,8 +615,8 @@ pref("browser.safebrowsing.provider.0.reportMalwareURL", "http://{moz:locale}.ma
 pref("browser.safebrowsing.provider.0.reportMalwareErrorURL", "http://{moz:locale}.malware-error.mozilla.com/?hl={moz:locale}");
 
 // FAQ URLs
-pref("browser.safebrowsing.warning.infoURL", "http://www.mozilla.com/%LOCALE%/%APP%/phishing-protection/");
-pref("browser.geolocation.warning.infoURL", "http://www.mozilla.com/%LOCALE%/%APP%/geolocation/");
+pref("browser.safebrowsing.warning.infoURL", "http://%LOCALE%.www.mozilla.com/%LOCALE%/firefox/phishing-protection/");
+pref("browser.geolocation.warning.infoURL", "http://%LOCALE%.www.mozilla.com/%LOCALE%/firefox/geolocation/");
 
 // Name of the about: page contributed by safebrowsing to handle display of error
 // pages on phishing/malware hits.  (bug 399233)
@@ -652,27 +633,25 @@ pref("urlclassifier.gethashtables", "goog-phish-shavar,goog-malware-shavar");
 // the database.
 pref("urlclassifier.confirm-age", 2700);
 
-//@line 745 "/icecat-3.6.8/browser/app/profile/firefox.js"
+//@line 715 "/icecat-3.6/browser/app/profile/firefox.js"
 
 // Maximum size of the sqlite3 cache during an update, in bytes
-//@line 748 "/icecat-3.6.8/browser/app/profile/firefox.js"
+//@line 718 "/icecat-3.6/browser/app/profile/firefox.js"
 pref("urlclassifier.updatecachemax", 104857600);
-//@line 752 "/icecat-3.6.8/browser/app/profile/firefox.js"
+//@line 722 "/icecat-3.6/browser/app/profile/firefox.js"
 
 // URL for checking the reason for a malware warning.
 pref("browser.safebrowsing.malware.reportURL", "http://safebrowsing.clients.google.com/safebrowsing/diagnostic?client=%NAME%&hl=%LOCALE%&site=");
 
-//@line 757 "/icecat-3.6.8/browser/app/profile/firefox.js"
+//@line 727 "/icecat-3.6/browser/app/profile/firefox.js"
 
 pref("browser.EULA.version", 3);
 pref("browser.rights.version", 3);
 pref("browser.rights.3.shown", false);
 
-//@line 766 "/icecat-3.6.8/browser/app/profile/firefox.js"
+//@line 736 "/icecat-3.6/browser/app/profile/firefox.js"
 
-//@line 770 "/icecat-3.6.8/browser/app/profile/firefox.js"
 pref("browser.sessionstore.resume_from_crash", true);
-//@line 772 "/icecat-3.6.8/browser/app/profile/firefox.js"
 pref("browser.sessionstore.resume_session_once", false);
 
 // minimal interval between two save operations in milliseconds
@@ -699,6 +678,18 @@ pref("accessibility.blockautorefresh", false);
 // when calculating frecency
 pref("places.frecency.numVisits", 10);
 
+// Number of records to update frecency for when idle.
+pref("places.frecency.numCalcOnIdle", 50);
+
+// Number of records to update frecency for when migrating from
+// a pre-frecency build.
+pref("places.frecency.numCalcOnMigrate", 50);
+
+// Perform frecency recalculation after this amount of idle, repeating.
+// A value of zero disables updating of frecency on idle.
+// Default is 1 minute (60000ms).
+pref("places.frecency.updateIdleTime", 60000);
+
 // buckets (in days) for frecency calculation
 pref("places.frecency.firstBucketCutoff", 4);
 pref("places.frecency.secondBucketCutoff", 14);
@@ -769,17 +760,6 @@ pref("browser.privatebrowsing.autostart", false);
 // Whether we should skip prompting before starting the private browsing mode
 pref("browser.privatebrowsing.dont_prompt_on_enter", false);
 
-// Don't try to alter this pref, it'll be reset the next time you use the
-// bookmarking dialog
-pref("browser.bookmarks.editDialog.firstEditField", "namePicker");
-
 // base url for the wifi geolocation network provider
 pref("geo.wifi.uri", "https://www.google.com/loc/json");
 
-//@line 905 "/icecat-3.6.8/browser/app/profile/firefox.js"
-
-// Whether to use a panel that looks like an OS X sheet for customization
-//@line 910 "/icecat-3.6.8/browser/app/profile/firefox.js"
-pref("toolbar.customization.usesheet", false);
-//@line 912 "/icecat-3.6.8/browser/app/profile/firefox.js"
-
